# Diameter Channel WSAdmin Jython Uninstall Script
#
# This script removes the Diameter Channel configuration
#
# Usage:
# wsadmin.sh -f <script_path> <cell> <node> <server_name> standalone|cluster [debug]
#     script_path:  path to this script
#     cell:  cell name (ie, myCell01)
#     node:  node name (ie, myNode01)
#     server_name:  server name (ie, server1)
#     standalone|cluster:  pass the word 'standalone' as the sixt parameter if
#                          this is a standalone server, otherwise pass 'cluster'
#     debug:  optional, just pass the word 'debug' as the fifth parameter to
#             enable debug

import sys

# Takes in a list from a WSAdmin object and creates a Jython list out of it
def wsadminToList(inStr):
        outList=[]
        if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
                tmpList = inStr[1:-1].split(" ")
        else:
                tmpList = inStr.split("\n")  #splits for Windows or Linux
        for item in tmpList:
                item = item.rstrip();        #removes any Windows "\r"
                if (len(item)>0):
                        outList.append(item)
        return outList
#endDef

# Strips out the []'s and the specified string
def stripOutStringAndBrackets(string, value):
	retVal = string.replace('[' + value, '')
	retVal = retVal.replace(']', '')
	retVal = retVal.strip()
	return retVal
#endDef

# Returns if debug is enabled
def isDebugEnabled():
	if 5 == len(sys.argv) and 'debug' == sys.argv[4]:
		return 1
	else:
		return 0
	#endIf
#endDef

# Returns if this is a cluster
def isCluster():
	if 'cluster' == sys.argv[3]:
		return 1
	else:
		return 0
	#endIf
#endDef

# Prints the usage
def printUsage():
	print 'Usage:\n\
	wsadmin.sh -f <script name> <cell> <node> <server name> standalone|cluster [debug]\n'
#endDef

# Removes the specified item
def removeItem(entries, attribute, value):
	if debug:
		print 'entering removeItem()\n\
		entries:  ' + str(entries) + '\n\
		attribute:  ' + attribute + '\n\
		value:  ' + value
		
	for entry in entries:
		if debug:
			print 'Current item is ' + entry
			
		entryName = AdminConfig.show(entry, attribute)
		entryName = stripOutStringAndBrackets(entryName, attribute)
		if debug:
			print 'entryName is. . . ' + entryName
	
		# If this is our victim, then remove it!
		if value == entryName:
			AdminConfig.remove(entry)
			if debug:
				print '-----Removed ' + entry
			#endIf
		#endIf
	#endFor
	
	if debug:
		print 'exiting removeItem()'
	#endIf
#endDef

# Prints the Copyright
def printCopyright():
	print '***************************************************************\n\n\
	Licensed Materials - Property of IBM\n\
	5724-O05\n\
	(c) Copyright IBM Corp. 2006, 2007 All Rights Reserved.\n\
	* Trademark of International Business Machines\n'
	print '***************************************************************'
#endDef

printCopyright()

# Get the Server ID
if 4 > len(sys.argv):
	printUsage()
	sys.exit(2)
#endIf

cell = sys.argv[0]
node = sys.argv[1]
serverName = sys.argv[2]
cluster = isCluster()

# See if debug is enabled
debug = isDebugEnabled()
if debug:
	print 'debug is enabled!'
	print 'Parameters are:\n\
	cell:  ' + cell + '\n\
	node:  ' + node + '\n\
	serverName:  ' + serverName + '\n\
	cluster:  ' + str(cluster)
#endIf
	

# Get the server id
serverID = AdminConfig.getid('/Server:' + serverName)
if debug:
	print 'ServerID is:  ' + serverID
#endIf

if '' == serverID:
	print 'Invalid Server Name "' + serverName + '"\n'
	printUsage()
	sys.exit(2)
#endIf

# Get the Server Name from AdminConfig
serverName = AdminConfig.show(serverID,'name')
if debug:
	print 'Server Name from AdminConfig:  ' + serverName
#endIf

# Strip out the 'name' and brackets
serverName = stripOutStringAndBrackets(serverName, 'name')
if debug:
	print 'Server Name stripped:   ' + serverName
#endIf

# Get the Node ID
nodeID = AdminConfig.getid('/Node:' + node)
if debug:
	print 'Node ID is:  ' + nodeID
#endIf

if '' == nodeID:
	print 'Invalid Node Name "' + node + '"\n'
	printUsage()
	sys.exit(2)
#endIf

# Get our server entries
entriesString = AdminConfig.list('ServerEntry', nodeID)
entries = wsadminToList(entriesString)

if debug:
	print 'Server Entries:  ' + str(entries)
#endIf

# Find the entry for our server
serverEntry = ''
for entry in entries:
	if debug:
		print 'Current entry is ' + entry
		
	serverEntryName = AdminConfig.show(entry, 'serverName')
	serverEntryName = stripOutStringAndBrackets(serverEntryName, 'serverName')
	
	if debug:
		print 'serverEntryName is. . .  ' + serverEntryName
        if (serverEntryName == serverName):
        	serverEntry = entry
        	if debug:
        		print 'Found our server entry:\n' + serverEntry
        #endIf 
#endFor

# Delete our endpoints
namedEndpointsString = AdminConfig.list('NamedEndPoint')
namedEndpoints = wsadminToList(namedEndpointsString)
if debug:
	print 'Named End Points:  ' + str(namedEndpoints)
#endIf

# Delete it
removeItem(namedEndpoints, 'endPointName', 'DiameterNamedEndPoint')

# Remove the ThreadPool
threadPoolsString = AdminConfig.list('ThreadPool', serverID)
threadPools = wsadminToList(threadPoolsString)
if debug:
	print 'Thread Pools ' + str(threadPools)
#endIf
	
# Delete it
removeItem(threadPools, 'name', 'DiameterThreadPool')

# Remove the Channels and the Chain, first the TCP inbound channel
tcpInboundChannelsString = AdminConfig.list('TCPInboundChannel', serverID)
tcpInboundChannels = wsadminToList(tcpInboundChannelsString)
if debug:
	print 'tcpInboundChannels:  ' + str(tcpInboundChannels)
#endIf

# Delete it
removeItem(tcpInboundChannels, 'name', 'DiameterTCPInboundChannel')

# SSL Inbound Channel
sslInboundChannelsString = AdminConfig.list('SSLInboundChannel', serverID)
sslInboundChannels = wsadminToList(sslInboundChannelsString)
if debug:
	print 'sslInboundChannels:  ' + str(sslInboundChannels)
#endIf

# Delete it
removeItem(sslInboundChannels, 'name', 'DiameterSSLInboundChannel')

# Generic Channels
genericInboundChannelsString = AdminConfig.list('GenericInboundChannel', serverID)
genericInboundChannels = wsadminToList(genericInboundChannelsString)
if debug:
	print 'genericInboundChannels:  ' + str(genericInboundChannels)
#endIf

# Delete the unsecure one
removeItem(genericInboundChannels, 'name', 'DiameterGenericInboundChannel')

# Update the list
genericInboundChannelsString = AdminConfig.list('GenericInboundChannel', serverID)
genericInboundChannels = wsadminToList(genericInboundChannelsString)
if debug:
	print 'genericInboundChannels:  ' + str(genericInboundChannels)
#endIf

# Delete the secure one
removeItem(genericInboundChannels, 'name', 'SecureDiameterGenericInboundChannel')

# The chains
chainsString = AdminConfig.list('Chain', serverID)
chains = wsadminToList(chainsString)
if debug:
	print 'chains:  ' + str(chains)
#endIf

# Delete the unsecure one
removeItem(chains, 'name', 'DiameterChain')

# Update the list
chainsString = AdminConfig.list('Chain', serverID)
chains = wsadminToList(chainsString)
if debug:
	print 'chains:  ' + str(chains)
#endIf

# Delete the secure one
removeItem(chains, 'name', 'SecureDiameterChain')

# Delete the workmanager
workManagersString = AdminConfig.list('WorkManagerInfo', serverID)
workManagers = wsadminToList(workManagersString)
if debug:
	print 'workManagers:  ' + str(workManagers)
#endIf

# Delete it
removeItem(workManagers, 'name', 'DiameterWorkManager')

# Form the parameter string for the SSL config
scope = ''
if (cluster):
	scope = ' (cell):' + cell + ' '
else:
	scope = ' (cell):' + cell + ':(node):' + node + ' '
#endIf
parameters = '[-alias Diameter -scopeName' + scope + ']'
if debug:
	print 'Scope:  \n' + scope + '\n\
	Parameters:  \n' + parameters
	
	print 'Deleting the SSL Config'
#endIf

AdminTask.deleteSSLConfig(parameters)	

# Save it! 
AdminConfig.save()
if debug:
	print 'Config has been saved'
#endIf

print 'Diameter Channels successfully removed on server ' + serverName + ' on node ' + node